@@ -99,11 +99,11 @@ class MinioAgent(ABC):
             else:
                 yield None
 
-    def has_object_not_been_analysed(self, object_name: str, bucket_name: str) -> bool:
+    def has_object_been_analysed(self, object_name: str, bucket_name: str) -> bool:
         tags = self.client.get_object_tags(bucket_name, object_name)
         if tags:
             try:
-                if tags[f"{self.name}-processed"] == "False":
+                if tags[f"{self.name}-processed"] == "True":
                     return True
                 else:
                     return False
@@ -115,12 +115,7 @@ class MinioAgent(ABC):
     def filter_objects_todo(
         self, object_names: List[str], bucket_name: str
     ) -> List[str]:
-        return list(
-            filter(
-                lambda name: self.has_object_not_been_analysed(name, bucket_name),
-                object_names,
-            )
-        )
+        return [name for name in object_names if not self.has_object_been_analysed(object_name=name, bucket_name)]
 
     def tag_objects_as_processed(
         self, object_names_processed: List[str], bucket_name: str
